OC.L10N.register(
    "viewer",
    {
    "View" : "Shiko",
    "Share" : "Ndaj"
},
"nplurals=2; plural=(n != 1);");
